@@ -11,5 +11,6 @@ from fluid.utils import (
 
 def main() -> None:
     config = load_config()
+    print(config)
     # setup_vscode(config["code"])
-    setup_environment(config["environment"])
+    # setup_environment(config["environment"])
