@@ -10,5 +10,5 @@ from typing import (
 
 
 def setup_environment(config: Dict) -> None:
-    # setup_tools(config["tools"])
+    setup_tools(config["tools"])
     setup_python_formatter(config["formatters"])
